# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_sale_listings200_response_inner_history20240624 import RentcastSaleListings200ResponseInnerHistory20240624

class TestRentcastSaleListings200ResponseInnerHistory20240624(unittest.TestCase):
    """RentcastSaleListings200ResponseInnerHistory20240624 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastSaleListings200ResponseInnerHistory20240624:
        """Test RentcastSaleListings200ResponseInnerHistory20240624
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastSaleListings200ResponseInnerHistory20240624`
        """
        model = RentcastSaleListings200ResponseInnerHistory20240624()
        if include_optional:
            return RentcastSaleListings200ResponseInnerHistory20240624(
                event = 'Sale Listing',
                price = 899000,
                listing_type = 'Standard',
                listed_date = '2024-06-24T00:00:00.000Z',
                removed_date = None,
                days_on_market = 99
            )
        else:
            return RentcastSaleListings200ResponseInnerHistory20240624(
        )
        """

    def testRentcastSaleListings200ResponseInnerHistory20240624(self):
        """Test RentcastSaleListings200ResponseInnerHistory20240624"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data import RentcastMarketStatistics200ResponseRentalData

class TestRentcastMarketStatistics200ResponseRentalData(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalData:
        """Test RentcastMarketStatistics200ResponseRentalData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalData`
        """
        model = RentcastMarketStatistics200ResponseRentalData()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalData(
                last_updated_date = '2024-10-14T00:00:00.000Z',
                average_rent = 1521,
                median_rent = 1495,
                min_rent = 750,
                max_rent = 2700,
                average_rent_per_square_foot = 1.38,
                median_rent_per_square_foot = 1.3,
                min_rent_per_square_foot = 0.86,
                max_rent_per_square_foot = 2.59,
                average_square_footage = 1175,
                median_square_footage = 1100,
                min_square_footage = 590,
                max_square_footage = 2100,
                average_days_on_market = 25,
                median_days_on_market = 8,
                min_days_on_market = 1,
                max_days_on_market = 304,
                new_listings = 18,
                total_listings = 76,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_rental_data_data_by_property_type_inner.market_statistics_200_response_rentalData_dataByPropertyType_inner(
                        property_type = 'Apartment', 
                        average_rent = 1148, 
                        median_rent = 1050, 
                        min_rent = 750, 
                        max_rent = 1975, 
                        average_rent_per_square_foot = 1.23, 
                        median_rent_per_square_foot = 1.13, 
                        min_rent_per_square_foot = 1.03, 
                        max_rent_per_square_foot = 1.59, 
                        average_square_footage = 957, 
                        median_square_footage = 950, 
                        min_square_footage = 650, 
                        max_square_footage = 1560, 
                        average_days_on_market = 17.43, 
                        median_days_on_market = 1, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 5, 
                        total_listings = 15, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_rental_data_data_by_bedrooms_inner.market_statistics_200_response_rentalData_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_rent = 842, 
                        median_rent = 850, 
                        min_rent = 750, 
                        max_rent = 945, 
                        average_rent_per_square_foot = 1.35, 
                        median_rent_per_square_foot = 1.3, 
                        min_rent_per_square_foot = 1.06, 
                        max_rent_per_square_foot = 1.57, 
                        average_square_footage = 679, 
                        median_square_footage = 650, 
                        min_square_footage = 590, 
                        max_square_footage = 800, 
                        average_days_on_market = 27.33, 
                        median_days_on_market = 9, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 1, 
                        total_listings = 7, )
                    ],
                history = rentcast_client.models.market_statistics_200_response_rental_data_history.market_statistics_200_response_rentalData_history(
                    2024_08 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08.market_statistics_200_response_rentalData_history_2024_08(
                        date = '2024-08-01T00:00:00.000Z', 
                        average_rent = 1496, 
                        median_rent = 1495, 
                        min_rent = 750, 
                        max_rent = 2800, 
                        average_rent_per_square_foot = 1.33, 
                        median_rent_per_square_foot = 1.27, 
                        min_rent_per_square_foot = 0.86, 
                        max_rent_per_square_foot = 2.52, 
                        average_square_footage = 1171, 
                        median_square_footage = 1100, 
                        min_square_footage = 650, 
                        max_square_footage = 2100, 
                        average_days_on_market = 66.49, 
                        median_days_on_market = 16, 
                        min_days_on_market = 1, 
                        max_days_on_market = 365, 
                        new_listings = 39, 
                        total_listings = 96, 
                        data_by_property_type = [
                            rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08_data_by_property_type_inner.market_statistics_200_response_rentalData_history_2024_08_dataByPropertyType_inner(
                                property_type = 'Apartment', 
                                average_rent = 1118, 
                                median_rent = 1050, 
                                min_rent = 750, 
                                max_rent = 1975, 
                                average_rent_per_square_foot = 1.24, 
                                median_rent_per_square_foot = 1.07, 
                                min_rent_per_square_foot = 0.98, 
                                max_rent_per_square_foot = 2.16, 
                                average_square_footage = 922, 
                                median_square_footage = 950, 
                                min_square_footage = 650, 
                                max_square_footage = 1560, 
                                average_days_on_market = 63.82, 
                                median_days_on_market = 17, 
                                min_days_on_market = 1, 
                                max_days_on_market = 365, 
                                new_listings = 8, 
                                total_listings = 23, )
                            ], 
                        data_by_bedrooms = [
                            rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08_data_by_bedrooms_inner.market_statistics_200_response_rentalData_history_2024_08_dataByBedrooms_inner(
                                bedrooms = 1, 
                                average_rent = 953, 
                                median_rent = 825, 
                                min_rent = 750, 
                                max_rent = 1610, 
                                average_rent_per_square_foot = 1.41, 
                                median_rent_per_square_foot = 1.3, 
                                min_rent_per_square_foot = 1.06, 
                                max_rent_per_square_foot = 2.16, 
                                average_square_footage = 732, 
                                median_square_footage = 675, 
                                min_square_footage = 650, 
                                max_square_footage = 950, 
                                average_days_on_market = 33.44, 
                                median_days_on_market = 17, 
                                min_days_on_market = 1, 
                                max_days_on_market = 124, 
                                new_listings = 3, 
                                total_listings = 10, )
                            ], ), 
                    2024_09 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_09.market_statistics_200_response_rentalData_history_2024_09(
                        date = '2024-09-01T00:00:00.000Z', 
                        average_rent = 1536, 
                        median_rent = 1550, 
                        min_rent = 750, 
                        max_rent = 2800, 
                        average_rent_per_square_foot = 1.38, 
                        median_rent_per_square_foot = 1.33, 
                        min_rent_per_square_foot = 0.86, 
                        max_rent_per_square_foot = 2.52, 
                        average_square_footage = 1180, 
                        median_square_footage = 1120, 
                        min_square_footage = 590, 
                        max_square_footage = 2100, 
                        average_days_on_market = 32.03, 
                        median_days_on_market = 8, 
                        min_days_on_market = 1, 
                        max_days_on_market = 365, 
                        new_listings = 33, 
                        total_listings = 80, ), 
                    2024_10 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_10.market_statistics_200_response_rentalData_history_2024_10(
                        date = '2024-10-01T00:00:00.000Z', 
                        average_rent = 1521, 
                        median_rent = 1495, 
                        min_rent = 750, 
                        max_rent = 2700, 
                        average_rent_per_square_foot = 1.38, 
                        median_rent_per_square_foot = 1.3, 
                        min_rent_per_square_foot = 0.86, 
                        max_rent_per_square_foot = 2.59, 
                        average_square_footage = 1175, 
                        median_square_footage = 1100, 
                        min_square_footage = 590, 
                        max_square_footage = 2100, 
                        average_days_on_market = 25, 
                        median_days_on_market = 8, 
                        min_days_on_market = 1, 
                        max_days_on_market = 304, 
                        new_listings = 18, 
                        total_listings = 76, ), )
            )
        else:
            return RentcastMarketStatistics200ResponseRentalData(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalData(self):
        """Test RentcastMarketStatistics200ResponseRentalData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2020 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2020
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2021 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2021
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2022 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2022
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2023 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2023
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2024 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2024
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class RentcastPropertyRecords200ResponseInnerPropertyTaxes(BaseModel):
    """
    RentcastPropertyRecords200ResponseInnerPropertyTaxes
    """ # noqa: E501
    var_2020: Optional[RentcastPropertyRecords200ResponseInnerPropertyTaxes2020] = Field(default=None, alias="2020")
    var_2021: Optional[RentcastPropertyRecords200ResponseInnerPropertyTaxes2021] = Field(default=None, alias="2021")
    var_2022: Optional[RentcastPropertyRecords200ResponseInnerPropertyTaxes2022] = Field(default=None, alias="2022")
    var_2023: Optional[RentcastPropertyRecords200ResponseInnerPropertyTaxes2023] = Field(default=None, alias="2023")
    var_2024: Optional[RentcastPropertyRecords200ResponseInnerPropertyTaxes2024] = Field(default=None, alias="2024")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["2020", "2021", "2022", "2023", "2024"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RentcastPropertyRecords200ResponseInnerPropertyTaxes from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of var_2020
        if self.var_2020:
            _dict['2020'] = self.var_2020.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2021
        if self.var_2021:
            _dict['2021'] = self.var_2021.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2022
        if self.var_2022:
            _dict['2022'] = self.var_2022.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2023
        if self.var_2023:
            _dict['2023'] = self.var_2023.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2024
        if self.var_2024:
            _dict['2024'] = self.var_2024.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RentcastPropertyRecords200ResponseInnerPropertyTaxes from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "2020": RentcastPropertyRecords200ResponseInnerPropertyTaxes2020.from_dict(obj["2020"]) if obj.get("2020") is not None else None,
            "2021": RentcastPropertyRecords200ResponseInnerPropertyTaxes2021.from_dict(obj["2021"]) if obj.get("2021") is not None else None,
            "2022": RentcastPropertyRecords200ResponseInnerPropertyTaxes2022.from_dict(obj["2022"]) if obj.get("2022") is not None else None,
            "2023": RentcastPropertyRecords200ResponseInnerPropertyTaxes2023.from_dict(obj["2023"]) if obj.get("2023") is not None else None,
            "2024": RentcastPropertyRecords200ResponseInnerPropertyTaxes2024.from_dict(obj["2024"]) if obj.get("2024") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202409_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseRentalDataHistory202409DataByBedroomsInner

class TestRentcastMarketStatistics200ResponseRentalDataHistory202409DataByBedroomsInner(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202409DataByBedroomsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202409DataByBedroomsInner:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202409DataByBedroomsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202409DataByBedroomsInner`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202409DataByBedroomsInner()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202409DataByBedroomsInner(
                bedrooms = 1,
                average_rent = 899,
                median_rent = 850,
                min_rent = 750,
                max_rent = 1300,
                average_rent_per_square_foot = 1.35,
                median_rent_per_square_foot = 1.37,
                min_rent_per_square_foot = 1.06,
                max_rent_per_square_foot = 1.57,
                average_square_footage = 733,
                median_square_footage = 675,
                min_square_footage = 590,
                max_square_footage = 950,
                average_days_on_market = 27.86,
                median_days_on_market = 21,
                min_days_on_market = 1,
                max_days_on_market = 80,
                new_listings = 3,
                total_listings = 8
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202409DataByBedroomsInner(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202409DataByBedroomsInner(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202409DataByBedroomsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_property_records200_response_inner_owner import RentcastPropertyRecords200ResponseInnerOwner

class TestRentcastPropertyRecords200ResponseInnerOwner(unittest.TestCase):
    """RentcastPropertyRecords200ResponseInnerOwner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastPropertyRecords200ResponseInnerOwner:
        """Test RentcastPropertyRecords200ResponseInnerOwner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastPropertyRecords200ResponseInnerOwner`
        """
        model = RentcastPropertyRecords200ResponseInnerOwner()
        if include_optional:
            return RentcastPropertyRecords200ResponseInnerOwner(
                names = [
                    'Michael Smith'
                    ],
                type = 'Individual',
                mailing_address = rentcast_client.models.property_records_200_response_inner_owner_mailing_address.property_records_200_response_inner_owner_mailingAddress(
                    id = '149-Weaver-Blvd,---264,-Weaverville,-NC-28787', 
                    formatted_address = '149 Weaver Blvd, # 264, Weaverville, NC 28787', 
                    address_line1 = '149 Weaver Blvd', 
                    address_line2 = '# 264', 
                    city = 'Weaverville', 
                    state = 'NC', 
                    zip_code = '28787', )
            )
        else:
            return RentcastPropertyRecords200ResponseInnerOwner(
        )
        """

    def testRentcastPropertyRecords200ResponseInnerOwner(self):
        """Test RentcastPropertyRecords200ResponseInnerOwner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class RentcastPropertyRecords200ResponseInnerFeatures(BaseModel):
    """
    RentcastPropertyRecords200ResponseInnerFeatures
    """ # noqa: E501
    architecture_type: Optional[StrictStr] = Field(default=None, alias="architectureType")
    cooling: Optional[StrictBool] = False
    cooling_type: Optional[StrictStr] = Field(default=None, alias="coolingType")
    exterior_type: Optional[StrictStr] = Field(default=None, alias="exteriorType")
    fireplace: Optional[StrictBool] = False
    fireplace_type: Optional[StrictStr] = Field(default=None, alias="fireplaceType")
    floor_count: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="floorCount")
    foundation_type: Optional[StrictStr] = Field(default=None, alias="foundationType")
    garage: Optional[StrictBool] = False
    garage_spaces: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="garageSpaces")
    garage_type: Optional[StrictStr] = Field(default=None, alias="garageType")
    heating: Optional[StrictBool] = False
    heating_type: Optional[StrictStr] = Field(default=None, alias="heatingType")
    pool: Optional[StrictBool] = False
    pool_type: Optional[StrictStr] = Field(default=None, alias="poolType")
    roof_type: Optional[StrictStr] = Field(default=None, alias="roofType")
    room_count: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="roomCount")
    unit_count: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="unitCount")
    view_type: Optional[StrictStr] = Field(default=None, alias="viewType")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["architectureType", "cooling", "coolingType", "exteriorType", "fireplace", "fireplaceType", "floorCount", "foundationType", "garage", "garageSpaces", "garageType", "heating", "heatingType", "pool", "poolType", "roofType", "roomCount", "unitCount", "viewType"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RentcastPropertyRecords200ResponseInnerFeatures from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RentcastPropertyRecords200ResponseInnerFeatures from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "architectureType": obj.get("architectureType"),
            "cooling": obj.get("cooling") if obj.get("cooling") is not None else False,
            "coolingType": obj.get("coolingType"),
            "exteriorType": obj.get("exteriorType"),
            "fireplace": obj.get("fireplace") if obj.get("fireplace") is not None else False,
            "fireplaceType": obj.get("fireplaceType"),
            "floorCount": obj.get("floorCount") if obj.get("floorCount") is not None else None,
            "foundationType": obj.get("foundationType"),
            "garage": obj.get("garage") if obj.get("garage") is not None else False,
            "garageSpaces": obj.get("garageSpaces") if obj.get("garageSpaces") is not None else None,
            "garageType": obj.get("garageType"),
            "heating": obj.get("heating") if obj.get("heating") is not None else False,
            "heatingType": obj.get("heatingType"),
            "pool": obj.get("pool") if obj.get("pool") is not None else False,
            "poolType": obj.get("poolType"),
            "roofType": obj.get("roofType"),
            "roomCount": obj.get("roomCount") if obj.get("roomCount") is not None else None,
            "unitCount": obj.get("unitCount") if obj.get("unitCount") is not None else None,
            "viewType": obj.get("viewType")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

# flake8: noqa
"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from rentcast_client.models.rentcast_market_statistics200_response import RentcastMarketStatistics200Response
from rentcast_client.models.rentcast_market_statistics200_response_rental_data import RentcastMarketStatistics200ResponseRentalData
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseRentalDataDataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_data_by_property_type_inner import RentcastMarketStatistics200ResponseRentalDataDataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history import RentcastMarketStatistics200ResponseRentalDataHistory
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202506 import RentcastMarketStatistics200ResponseRentalDataHistory202506
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202506_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202506_data_by_property_type_inner import RentcastMarketStatistics200ResponseRentalDataHistory202506DataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202507 import RentcastMarketStatistics200ResponseRentalDataHistory202507
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202507_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseRentalDataHistory202507DataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202507_data_by_property_type_inner import RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202508 import RentcastMarketStatistics200ResponseRentalDataHistory202508
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202508_data_by_property_type_inner import RentcastMarketStatistics200ResponseRentalDataHistory202508DataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data import RentcastMarketStatistics200ResponseSaleData
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseSaleDataDataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_data_by_property_type_inner import RentcastMarketStatistics200ResponseSaleDataDataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history import RentcastMarketStatistics200ResponseSaleDataHistory
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202506 import RentcastMarketStatistics200ResponseSaleDataHistory202506
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202506_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseSaleDataHistory202506DataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202506_data_by_property_type_inner import RentcastMarketStatistics200ResponseSaleDataHistory202506DataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202507 import RentcastMarketStatistics200ResponseSaleDataHistory202507
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202507_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseSaleDataHistory202507DataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202507_data_by_property_type_inner import RentcastMarketStatistics200ResponseSaleDataHistory202507DataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202508 import RentcastMarketStatistics200ResponseSaleDataHistory202508
from rentcast_client.models.rentcast_property_records200_response_inner import RentcastPropertyRecords200ResponseInner
from rentcast_client.models.rentcast_property_records200_response_inner_features import RentcastPropertyRecords200ResponseInnerFeatures
from rentcast_client.models.rentcast_property_records200_response_inner_history import RentcastPropertyRecords200ResponseInnerHistory
from rentcast_client.models.rentcast_property_records200_response_inner_history20171019 import RentcastPropertyRecords200ResponseInnerHistory20171019
from rentcast_client.models.rentcast_property_records200_response_inner_history20241118 import RentcastPropertyRecords200ResponseInnerHistory20241118
from rentcast_client.models.rentcast_property_records200_response_inner_hoa import RentcastPropertyRecords200ResponseInnerHoa
from rentcast_client.models.rentcast_property_records200_response_inner_owner import RentcastPropertyRecords200ResponseInnerOwner
from rentcast_client.models.rentcast_property_records200_response_inner_owner_mailing_address import RentcastPropertyRecords200ResponseInnerOwnerMailingAddress
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes import RentcastPropertyRecords200ResponseInnerPropertyTaxes
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2020 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2020
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2021 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2021
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2022 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2022
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2023 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2023
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2024 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2024
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments import RentcastPropertyRecords200ResponseInnerTaxAssessments
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments2020 import RentcastPropertyRecords200ResponseInnerTaxAssessments2020
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments2021 import RentcastPropertyRecords200ResponseInnerTaxAssessments2021
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments2022 import RentcastPropertyRecords200ResponseInnerTaxAssessments2022
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments2023 import RentcastPropertyRecords200ResponseInnerTaxAssessments2023
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments2024 import RentcastPropertyRecords200ResponseInnerTaxAssessments2024
from rentcast_client.models.rentcast_property_records401_response import RentcastPropertyRecords401Response
from rentcast_client.models.rentcast_rent_estimate_long_term200_response import RentcastRentEstimateLongTerm200Response
from rentcast_client.models.rentcast_rent_estimate_long_term200_response_comparables_inner import RentcastRentEstimateLongTerm200ResponseComparablesInner
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner import RentcastRentalListingsLongTerm200ResponseInner
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_history import RentcastRentalListingsLongTerm200ResponseInnerHistory
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_history20240918 import RentcastRentalListingsLongTerm200ResponseInnerHistory20240918
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_hoa import RentcastRentalListingsLongTerm200ResponseInnerHoa
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_listing_agent import RentcastRentalListingsLongTerm200ResponseInnerListingAgent
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_listing_office import RentcastRentalListingsLongTerm200ResponseInnerListingOffice
from rentcast_client.models.rentcast_sale_listing_by_id200_response import RentcastSaleListingById200Response
from rentcast_client.models.rentcast_sale_listings200_response_inner import RentcastSaleListings200ResponseInner
from rentcast_client.models.rentcast_sale_listings200_response_inner_history import RentcastSaleListings200ResponseInnerHistory
from rentcast_client.models.rentcast_sale_listings200_response_inner_history20240624 import RentcastSaleListings200ResponseInnerHistory20240624
from rentcast_client.models.rentcast_sale_listings200_response_inner_hoa import RentcastSaleListings200ResponseInnerHoa
from rentcast_client.models.rentcast_sale_listings200_response_inner_listing_agent import RentcastSaleListings200ResponseInnerListingAgent
from rentcast_client.models.rentcast_sale_listings200_response_inner_listing_office import RentcastSaleListings200ResponseInnerListingOffice
from rentcast_client.models.rentcast_value_estimate200_response import RentcastValueEstimate200Response
from rentcast_client.models.rentcast_value_estimate200_response_comparables_inner import RentcastValueEstimate200ResponseComparablesInner
from rentcast_client.models.rentcast_value_estimate200_response_subject_property import RentcastValueEstimate200ResponseSubjectProperty
from rentcast_client.models.rentcast_value_estimate401_response import RentcastValueEstimate401Response

